# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class EtudesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def studies_count_get(self, **kwargs):
        """
        Nombre d'études
        Compte le nombre d'études par rapport à certains critères de recherches.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.studies_count_get(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int _from: Début de la pagination
        :param int size: Nombre de résultats
        :param str sort: Trier par
        :param list[str] includes: Inclure un ou plusieurs élements par identifiant
        :param list[str] excludes: Exclure un ou plusieurs élements par identifiant
        :param list[int] user_ids: Liste d'identifiants d'utilisateurs
        :param list[str] external_user_ids: Liste d'identifiants externe client
        :param list[int] agency_ids: Liste d'identifiants d'agences
        :param list[str] external_agency_ids: Liste d'identifiants externes d'agences
        :param list[int] organization_ids: Liste d'identifiants d'organisations
        :param list[str] marketing_types: Liste de types de marché (vente, location, vente en viager)
        :param list[str] property_external_ids: Liste d'identifiants externes de biens
        :param datetime creation_date_min: Date minimale de création de l'étude
        :param datetime creation_date_max: Date limite de création de l'étude
        :return: CountResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.studies_count_get_with_http_info(**kwargs)
        else:
            (data) = self.studies_count_get_with_http_info(**kwargs)
            return data

    def studies_count_get_with_http_info(self, **kwargs):
        """
        Nombre d'études
        Compte le nombre d'études par rapport à certains critères de recherches.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.studies_count_get_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int _from: Début de la pagination
        :param int size: Nombre de résultats
        :param str sort: Trier par
        :param list[str] includes: Inclure un ou plusieurs élements par identifiant
        :param list[str] excludes: Exclure un ou plusieurs élements par identifiant
        :param list[int] user_ids: Liste d'identifiants d'utilisateurs
        :param list[str] external_user_ids: Liste d'identifiants externe client
        :param list[int] agency_ids: Liste d'identifiants d'agences
        :param list[str] external_agency_ids: Liste d'identifiants externes d'agences
        :param list[int] organization_ids: Liste d'identifiants d'organisations
        :param list[str] marketing_types: Liste de types de marché (vente, location, vente en viager)
        :param list[str] property_external_ids: Liste d'identifiants externes de biens
        :param datetime creation_date_min: Date minimale de création de l'étude
        :param datetime creation_date_max: Date limite de création de l'étude
        :return: CountResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'size', 'sort', 'includes', 'excludes', 'user_ids', 'external_user_ids', 'agency_ids', 'external_agency_ids', 'organization_ids', 'marketing_types', 'property_external_ids', 'creation_date_min', 'creation_date_max']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method studies_count_get" % key
                )
            params[key] = val
        del params['kwargs']

        if '_from' in params and params['_from'] < 0:
            raise ValueError("Invalid value for parameter `_from` when calling `studies_count_get`, must be a value greater than or equal to `0`")
        if 'size' in params and params['size'] > 1000:
            raise ValueError("Invalid value for parameter `size` when calling `studies_count_get`, must be a value less than or equal to `1000`")
        if 'size' in params and params['size'] < 0:
            raise ValueError("Invalid value for parameter `size` when calling `studies_count_get`, must be a value greater than or equal to `0`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))
        if 'size' in params:
            query_params.append(('size', params['size']))
        if 'sort' in params:
            query_params.append(('sort', params['sort']))
        if 'includes' in params:
            query_params.append(('includes', params['includes']))
            collection_formats['includes'] = 'multi'
        if 'excludes' in params:
            query_params.append(('excludes', params['excludes']))
            collection_formats['excludes'] = 'multi'
        if 'user_ids' in params:
            query_params.append(('userIds', params['user_ids']))
            collection_formats['userIds'] = 'csv'
        if 'external_user_ids' in params:
            query_params.append(('externalUserIds', params['external_user_ids']))
            collection_formats['externalUserIds'] = 'csv'
        if 'agency_ids' in params:
            query_params.append(('agencyIds', params['agency_ids']))
            collection_formats['agencyIds'] = 'csv'
        if 'external_agency_ids' in params:
            query_params.append(('externalAgencyIds', params['external_agency_ids']))
            collection_formats['externalAgencyIds'] = 'csv'
        if 'organization_ids' in params:
            query_params.append(('organizationIds', params['organization_ids']))
            collection_formats['organizationIds'] = 'csv'
        if 'marketing_types' in params:
            query_params.append(('marketingTypes', params['marketing_types']))
            collection_formats['marketingTypes'] = 'csv'
        if 'property_external_ids' in params:
            query_params.append(('propertyExternalIds', params['property_external_ids']))
            collection_formats['propertyExternalIds'] = 'csv'
        if 'creation_date_min' in params:
            query_params.append(('creationDateMin', params['creation_date_min']))
        if 'creation_date_max' in params:
            query_params.append(('creationDateMax', params['creation_date_max']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/studies/count', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='CountResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def studies_get(self, **kwargs):
        """
        Rechercher des études
        Rechercher des études selon plusieurs critères
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.studies_get(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int _from: Début de la pagination
        :param int size: Nombre de résultats
        :param str sort: Trier par
        :param list[str] includes: Inclure un ou plusieurs élements par identifiant
        :param list[str] excludes: Exclure un ou plusieurs élements par identifiant
        :param list[int] user_ids: Liste d'identifiants d'utilisateurs
        :param list[str] external_user_ids: Liste d'identifiants externe client
        :param list[int] agency_ids: Liste d'identifiants d'agences
        :param list[str] external_agency_ids: Liste d'identifiants externes d'agences
        :param list[int] organization_ids: Liste d'identifiants d'organisations
        :param list[str] marketing_types: Liste de types de marché (vente, location, vente en viager)
        :param list[str] property_external_ids: Liste d'identifiants externes de biens
        :param datetime creation_date_min: Date minimale de création de l'étude
        :param datetime creation_date_max: Date limite de création de l'étude
        :return: InlineResponse2007
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.studies_get_with_http_info(**kwargs)
        else:
            (data) = self.studies_get_with_http_info(**kwargs)
            return data

    def studies_get_with_http_info(self, **kwargs):
        """
        Rechercher des études
        Rechercher des études selon plusieurs critères
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.studies_get_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int _from: Début de la pagination
        :param int size: Nombre de résultats
        :param str sort: Trier par
        :param list[str] includes: Inclure un ou plusieurs élements par identifiant
        :param list[str] excludes: Exclure un ou plusieurs élements par identifiant
        :param list[int] user_ids: Liste d'identifiants d'utilisateurs
        :param list[str] external_user_ids: Liste d'identifiants externe client
        :param list[int] agency_ids: Liste d'identifiants d'agences
        :param list[str] external_agency_ids: Liste d'identifiants externes d'agences
        :param list[int] organization_ids: Liste d'identifiants d'organisations
        :param list[str] marketing_types: Liste de types de marché (vente, location, vente en viager)
        :param list[str] property_external_ids: Liste d'identifiants externes de biens
        :param datetime creation_date_min: Date minimale de création de l'étude
        :param datetime creation_date_max: Date limite de création de l'étude
        :return: InlineResponse2007
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'size', 'sort', 'includes', 'excludes', 'user_ids', 'external_user_ids', 'agency_ids', 'external_agency_ids', 'organization_ids', 'marketing_types', 'property_external_ids', 'creation_date_min', 'creation_date_max']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method studies_get" % key
                )
            params[key] = val
        del params['kwargs']

        if '_from' in params and params['_from'] < 0:
            raise ValueError("Invalid value for parameter `_from` when calling `studies_get`, must be a value greater than or equal to `0`")
        if 'size' in params and params['size'] > 1000:
            raise ValueError("Invalid value for parameter `size` when calling `studies_get`, must be a value less than or equal to `1000`")
        if 'size' in params and params['size'] < 0:
            raise ValueError("Invalid value for parameter `size` when calling `studies_get`, must be a value greater than or equal to `0`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))
        if 'size' in params:
            query_params.append(('size', params['size']))
        if 'sort' in params:
            query_params.append(('sort', params['sort']))
        if 'includes' in params:
            query_params.append(('includes', params['includes']))
            collection_formats['includes'] = 'multi'
        if 'excludes' in params:
            query_params.append(('excludes', params['excludes']))
            collection_formats['excludes'] = 'multi'
        if 'user_ids' in params:
            query_params.append(('userIds', params['user_ids']))
            collection_formats['userIds'] = 'csv'
        if 'external_user_ids' in params:
            query_params.append(('externalUserIds', params['external_user_ids']))
            collection_formats['externalUserIds'] = 'csv'
        if 'agency_ids' in params:
            query_params.append(('agencyIds', params['agency_ids']))
            collection_formats['agencyIds'] = 'csv'
        if 'external_agency_ids' in params:
            query_params.append(('externalAgencyIds', params['external_agency_ids']))
            collection_formats['externalAgencyIds'] = 'csv'
        if 'organization_ids' in params:
            query_params.append(('organizationIds', params['organization_ids']))
            collection_formats['organizationIds'] = 'csv'
        if 'marketing_types' in params:
            query_params.append(('marketingTypes', params['marketing_types']))
            collection_formats['marketingTypes'] = 'csv'
        if 'property_external_ids' in params:
            query_params.append(('propertyExternalIds', params['property_external_ids']))
            collection_formats['propertyExternalIds'] = 'csv'
        if 'creation_date_min' in params:
            query_params.append(('creationDateMin', params['creation_date_min']))
        if 'creation_date_max' in params:
            query_params.append(('creationDateMax', params['creation_date_max']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/studies', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InlineResponse2007',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def studies_id_delete(self, id, **kwargs):
        """
        Supprimer une étude
        Supprimer une étude par son identifiant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.studies_id_delete(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: L'identifiant de l'étude (required)
        :return: DefaultResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.studies_id_delete_with_http_info(id, **kwargs)
        else:
            (data) = self.studies_id_delete_with_http_info(id, **kwargs)
            return data

    def studies_id_delete_with_http_info(self, id, **kwargs):
        """
        Supprimer une étude
        Supprimer une étude par son identifiant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.studies_id_delete_with_http_info(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: L'identifiant de l'étude (required)
        :return: DefaultResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method studies_id_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `studies_id_delete`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/studies/{id}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='DefaultResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def studies_id_duplicate_get(self, id, **kwargs):
        """
        Dupliquer une étude
        Dupliquer une étude par son identifiant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.studies_id_duplicate_get(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: L'identifiant de l'étude (required)
        :return: Study
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.studies_id_duplicate_get_with_http_info(id, **kwargs)
        else:
            (data) = self.studies_id_duplicate_get_with_http_info(id, **kwargs)
            return data

    def studies_id_duplicate_get_with_http_info(self, id, **kwargs):
        """
        Dupliquer une étude
        Dupliquer une étude par son identifiant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.studies_id_duplicate_get_with_http_info(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: L'identifiant de l'étude (required)
        :return: Study
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method studies_id_duplicate_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `studies_id_duplicate_get`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/studies/{id}/duplicate', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Study',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def studies_id_get(self, id, **kwargs):
        """
        Récupérer une étude
        Récupérer une étude par son identifiant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.studies_id_get(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: L'identifiant de l'étude (required)
        :return: Study
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.studies_id_get_with_http_info(id, **kwargs)
        else:
            (data) = self.studies_id_get_with_http_info(id, **kwargs)
            return data

    def studies_id_get_with_http_info(self, id, **kwargs):
        """
        Récupérer une étude
        Récupérer une étude par son identifiant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.studies_id_get_with_http_info(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: L'identifiant de l'étude (required)
        :return: Study
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method studies_id_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `studies_id_get`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/studies/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Study',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def studies_id_put(self, id, **kwargs):
        """
        Mettre à jour une étude
        Mettre à jour une étude par son identifiant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.studies_id_put(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: L'identifiant de l'étude (required)
        :return: Study
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.studies_id_put_with_http_info(id, **kwargs)
        else:
            (data) = self.studies_id_put_with_http_info(id, **kwargs)
            return data

    def studies_id_put_with_http_info(self, id, **kwargs):
        """
        Mettre à jour une étude
        Mettre à jour une étude par son identifiant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.studies_id_put_with_http_info(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: L'identifiant de l'étude (required)
        :return: Study
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method studies_id_put" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `studies_id_put`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/studies/{id}', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Study',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def studies_post(self, body, **kwargs):
        """
        Créer une étude
        Retourne l'étude créé
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.studies_post(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Body2 body: Formulaire pour la création d'une étude (required)
        :return: Study
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.studies_post_with_http_info(body, **kwargs)
        else:
            (data) = self.studies_post_with_http_info(body, **kwargs)
            return data

    def studies_post_with_http_info(self, body, **kwargs):
        """
        Créer une étude
        Retourne l'étude créé
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.studies_post_with_http_info(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Body2 body: Formulaire pour la création d'une étude (required)
        :return: Study
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method studies_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `studies_post`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/studies', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Study',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PriceEvent(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'price': 'float',
        'date': 'datetime'
    }

    attribute_map = {
        'price': 'price',
        'date': 'date'
    }

    def __init__(self, price=None, date=None):
        """
        PriceEvent - a model defined in Swagger
        """

        self._price = None
        self._date = None

        if price is not None:
          self.price = price
        if date is not None:
          self.date = date

    @property
    def price(self):
        """
        Gets the price of this PriceEvent.

        :return: The price of this PriceEvent.
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """
        Sets the price of this PriceEvent.

        :param price: The price of this PriceEvent.
        :type: float
        """

        self._price = price

    @property
    def date(self):
        """
        Gets the date of this PriceEvent.

        :return: The date of this PriceEvent.
        :rtype: datetime
        """
        return self._date

    @date.setter
    def date(self, date):
        """
        Sets the date of this PriceEvent.

        :param date: The date of this PriceEvent.
        :type: datetime
        """

        self._date = date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PriceEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class City(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'insee_code': 'str',
        'dept_code': 'str',
        'dept_name': 'str',
        'zip_codes': 'list[str]',
        'localities': 'list[str]',
        'name': 'str',
        'usage_name': 'str',
        'region_name': 'str',
        'population': 'float',
        'centroid': 'Location',
        'geometry': 'object'
    }

    attribute_map = {
        'id': 'id',
        'insee_code': 'inseeCode',
        'dept_code': 'deptCode',
        'dept_name': 'deptName',
        'zip_codes': 'zipCodes',
        'localities': 'localities',
        'name': 'name',
        'usage_name': 'usageName',
        'region_name': 'regionName',
        'population': 'population',
        'centroid': 'centroid',
        'geometry': 'geometry'
    }

    def __init__(self, id=None, insee_code=None, dept_code=None, dept_name=None, zip_codes=None, localities=None, name=None, usage_name=None, region_name=None, population=None, centroid=None, geometry=None):
        """
        City - a model defined in Swagger
        """

        self._id = None
        self._insee_code = None
        self._dept_code = None
        self._dept_name = None
        self._zip_codes = None
        self._localities = None
        self._name = None
        self._usage_name = None
        self._region_name = None
        self._population = None
        self._centroid = None
        self._geometry = None

        if id is not None:
          self.id = id
        if insee_code is not None:
          self.insee_code = insee_code
        if dept_code is not None:
          self.dept_code = dept_code
        if dept_name is not None:
          self.dept_name = dept_name
        if zip_codes is not None:
          self.zip_codes = zip_codes
        if localities is not None:
          self.localities = localities
        if name is not None:
          self.name = name
        if usage_name is not None:
          self.usage_name = usage_name
        if region_name is not None:
          self.region_name = region_name
        if population is not None:
          self.population = population
        if centroid is not None:
          self.centroid = centroid
        if geometry is not None:
          self.geometry = geometry

    @property
    def id(self):
        """
        Gets the id of this City.

        :return: The id of this City.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this City.

        :param id: The id of this City.
        :type: int
        """

        self._id = id

    @property
    def insee_code(self):
        """
        Gets the insee_code of this City.

        :return: The insee_code of this City.
        :rtype: str
        """
        return self._insee_code

    @insee_code.setter
    def insee_code(self, insee_code):
        """
        Sets the insee_code of this City.

        :param insee_code: The insee_code of this City.
        :type: str
        """

        self._insee_code = insee_code

    @property
    def dept_code(self):
        """
        Gets the dept_code of this City.

        :return: The dept_code of this City.
        :rtype: str
        """
        return self._dept_code

    @dept_code.setter
    def dept_code(self, dept_code):
        """
        Sets the dept_code of this City.

        :param dept_code: The dept_code of this City.
        :type: str
        """

        self._dept_code = dept_code

    @property
    def dept_name(self):
        """
        Gets the dept_name of this City.

        :return: The dept_name of this City.
        :rtype: str
        """
        return self._dept_name

    @dept_name.setter
    def dept_name(self, dept_name):
        """
        Sets the dept_name of this City.

        :param dept_name: The dept_name of this City.
        :type: str
        """

        self._dept_name = dept_name

    @property
    def zip_codes(self):
        """
        Gets the zip_codes of this City.

        :return: The zip_codes of this City.
        :rtype: list[str]
        """
        return self._zip_codes

    @zip_codes.setter
    def zip_codes(self, zip_codes):
        """
        Sets the zip_codes of this City.

        :param zip_codes: The zip_codes of this City.
        :type: list[str]
        """

        self._zip_codes = zip_codes

    @property
    def localities(self):
        """
        Gets the localities of this City.

        :return: The localities of this City.
        :rtype: list[str]
        """
        return self._localities

    @localities.setter
    def localities(self, localities):
        """
        Sets the localities of this City.

        :param localities: The localities of this City.
        :type: list[str]
        """

        self._localities = localities

    @property
    def name(self):
        """
        Gets the name of this City.

        :return: The name of this City.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this City.

        :param name: The name of this City.
        :type: str
        """

        self._name = name

    @property
    def usage_name(self):
        """
        Gets the usage_name of this City.

        :return: The usage_name of this City.
        :rtype: str
        """
        return self._usage_name

    @usage_name.setter
    def usage_name(self, usage_name):
        """
        Sets the usage_name of this City.

        :param usage_name: The usage_name of this City.
        :type: str
        """

        self._usage_name = usage_name

    @property
    def region_name(self):
        """
        Gets the region_name of this City.

        :return: The region_name of this City.
        :rtype: str
        """
        return self._region_name

    @region_name.setter
    def region_name(self, region_name):
        """
        Sets the region_name of this City.

        :param region_name: The region_name of this City.
        :type: str
        """

        self._region_name = region_name

    @property
    def population(self):
        """
        Gets the population of this City.

        :return: The population of this City.
        :rtype: float
        """
        return self._population

    @population.setter
    def population(self, population):
        """
        Sets the population of this City.

        :param population: The population of this City.
        :type: float
        """

        self._population = population

    @property
    def centroid(self):
        """
        Gets the centroid of this City.

        :return: The centroid of this City.
        :rtype: Location
        """
        return self._centroid

    @centroid.setter
    def centroid(self, centroid):
        """
        Sets the centroid of this City.

        :param centroid: The centroid of this City.
        :type: Location
        """

        self._centroid = centroid

    @property
    def geometry(self):
        """
        Gets the geometry of this City.

        :return: The geometry of this City.
        :rtype: object
        """
        return self._geometry

    @geometry.setter
    def geometry(self, geometry):
        """
        Sets the geometry of this City.

        :param geometry: The geometry of this City.
        :type: object
        """

        self._geometry = geometry

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, City):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ad(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'url': 'str',
        'crawl_source': 'CrawlSource',
        'last_crawl_date': 'datetime',
        '_property': 'ModelProperty'
    }

    attribute_map = {
        'id': 'id',
        'url': 'url',
        'crawl_source': 'crawlSource',
        'last_crawl_date': 'lastCrawlDate',
        '_property': 'property'
    }

    def __init__(self, id=None, url=None, crawl_source=None, last_crawl_date=None, _property=None):
        """
        Ad - a model defined in Swagger
        """

        self._id = None
        self._url = None
        self._crawl_source = None
        self._last_crawl_date = None
        self.__property = None

        if id is not None:
          self.id = id
        if url is not None:
          self.url = url
        if crawl_source is not None:
          self.crawl_source = crawl_source
        if last_crawl_date is not None:
          self.last_crawl_date = last_crawl_date
        if _property is not None:
          self._property = _property

    @property
    def id(self):
        """
        Gets the id of this Ad.

        :return: The id of this Ad.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Ad.

        :param id: The id of this Ad.
        :type: str
        """

        self._id = id

    @property
    def url(self):
        """
        Gets the url of this Ad.

        :return: The url of this Ad.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this Ad.

        :param url: The url of this Ad.
        :type: str
        """

        self._url = url

    @property
    def crawl_source(self):
        """
        Gets the crawl_source of this Ad.

        :return: The crawl_source of this Ad.
        :rtype: CrawlSource
        """
        return self._crawl_source

    @crawl_source.setter
    def crawl_source(self, crawl_source):
        """
        Sets the crawl_source of this Ad.

        :param crawl_source: The crawl_source of this Ad.
        :type: CrawlSource
        """

        self._crawl_source = crawl_source

    @property
    def last_crawl_date(self):
        """
        Gets the last_crawl_date of this Ad.

        :return: The last_crawl_date of this Ad.
        :rtype: datetime
        """
        return self._last_crawl_date

    @last_crawl_date.setter
    def last_crawl_date(self, last_crawl_date):
        """
        Sets the last_crawl_date of this Ad.

        :param last_crawl_date: The last_crawl_date of this Ad.
        :type: datetime
        """

        self._last_crawl_date = last_crawl_date

    @property
    def _property(self):
        """
        Gets the _property of this Ad.

        :return: The _property of this Ad.
        :rtype: ModelProperty
        """
        return self.__property

    @_property.setter
    def _property(self, _property):
        """
        Sets the _property of this Ad.

        :param _property: The _property of this Ad.
        :type: ModelProperty
        """

        self.__property = _property

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ad):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Body(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'raw_address': 'str',
        'surface': 'float',
        'room_count': 'int',
        'price': 'float',
        'furnished': 'bool',
        'construction_period': 'Range'
    }

    attribute_map = {
        'raw_address': 'rawAddress',
        'surface': 'surface',
        'room_count': 'roomCount',
        'price': 'price',
        'furnished': 'furnished',
        'construction_period': 'constructionPeriod'
    }

    def __init__(self, raw_address=None, surface=None, room_count=None, price=None, furnished=None, construction_period=None):
        """
        Body - a model defined in Swagger
        """

        self._raw_address = None
        self._surface = None
        self._room_count = None
        self._price = None
        self._furnished = None
        self._construction_period = None

        self.raw_address = raw_address
        self.surface = surface
        self.room_count = room_count
        self.price = price
        if furnished is not None:
          self.furnished = furnished
        if construction_period is not None:
          self.construction_period = construction_period

    @property
    def raw_address(self):
        """
        Gets the raw_address of this Body.

        :return: The raw_address of this Body.
        :rtype: str
        """
        return self._raw_address

    @raw_address.setter
    def raw_address(self, raw_address):
        """
        Sets the raw_address of this Body.

        :param raw_address: The raw_address of this Body.
        :type: str
        """
        if raw_address is None:
            raise ValueError("Invalid value for `raw_address`, must not be `None`")

        self._raw_address = raw_address

    @property
    def surface(self):
        """
        Gets the surface of this Body.

        :return: The surface of this Body.
        :rtype: float
        """
        return self._surface

    @surface.setter
    def surface(self, surface):
        """
        Sets the surface of this Body.

        :param surface: The surface of this Body.
        :type: float
        """
        if surface is None:
            raise ValueError("Invalid value for `surface`, must not be `None`")

        self._surface = surface

    @property
    def room_count(self):
        """
        Gets the room_count of this Body.

        :return: The room_count of this Body.
        :rtype: int
        """
        return self._room_count

    @room_count.setter
    def room_count(self, room_count):
        """
        Sets the room_count of this Body.

        :param room_count: The room_count of this Body.
        :type: int
        """
        if room_count is None:
            raise ValueError("Invalid value for `room_count`, must not be `None`")

        self._room_count = room_count

    @property
    def price(self):
        """
        Gets the price of this Body.

        :return: The price of this Body.
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """
        Sets the price of this Body.

        :param price: The price of this Body.
        :type: float
        """
        if price is None:
            raise ValueError("Invalid value for `price`, must not be `None`")

        self._price = price

    @property
    def furnished(self):
        """
        Gets the furnished of this Body.

        :return: The furnished of this Body.
        :rtype: bool
        """
        return self._furnished

    @furnished.setter
    def furnished(self, furnished):
        """
        Sets the furnished of this Body.

        :param furnished: The furnished of this Body.
        :type: bool
        """

        self._furnished = furnished

    @property
    def construction_period(self):
        """
        Gets the construction_period of this Body.

        :return: The construction_period of this Body.
        :rtype: Range
        """
        return self._construction_period

    @construction_period.setter
    def construction_period(self, construction_period):
        """
        Sets the construction_period of this Body.

        :param construction_period: The construction_period of this Body.
        :type: Range
        """

        self._construction_period = construction_period

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Body):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class MandataryNetwork(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'description': 'str',
        'siren': 'str',
        'siret': 'str',
        'address': 'Address',
        'phone': 'str',
        'email': 'str',
        'url': 'str',
        'image_url': 'str',
        'active': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'siren': 'siren',
        'siret': 'siret',
        'address': 'address',
        'phone': 'phone',
        'email': 'email',
        'url': 'url',
        'image_url': 'imageUrl',
        'active': 'active'
    }

    def __init__(self, id=None, name=None, description=None, siren=None, siret=None, address=None, phone=None, email=None, url=None, image_url=None, active=None):
        """
        MandataryNetwork - a model defined in Swagger
        """

        self._id = None
        self._name = None
        self._description = None
        self._siren = None
        self._siret = None
        self._address = None
        self._phone = None
        self._email = None
        self._url = None
        self._image_url = None
        self._active = None

        if id is not None:
          self.id = id
        if name is not None:
          self.name = name
        if description is not None:
          self.description = description
        if siren is not None:
          self.siren = siren
        if siret is not None:
          self.siret = siret
        if address is not None:
          self.address = address
        if phone is not None:
          self.phone = phone
        if email is not None:
          self.email = email
        if url is not None:
          self.url = url
        if image_url is not None:
          self.image_url = image_url
        if active is not None:
          self.active = active

    @property
    def id(self):
        """
        Gets the id of this MandataryNetwork.

        :return: The id of this MandataryNetwork.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this MandataryNetwork.

        :param id: The id of this MandataryNetwork.
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this MandataryNetwork.

        :return: The name of this MandataryNetwork.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this MandataryNetwork.

        :param name: The name of this MandataryNetwork.
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """
        Gets the description of this MandataryNetwork.

        :return: The description of this MandataryNetwork.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this MandataryNetwork.

        :param description: The description of this MandataryNetwork.
        :type: str
        """

        self._description = description

    @property
    def siren(self):
        """
        Gets the siren of this MandataryNetwork.

        :return: The siren of this MandataryNetwork.
        :rtype: str
        """
        return self._siren

    @siren.setter
    def siren(self, siren):
        """
        Sets the siren of this MandataryNetwork.

        :param siren: The siren of this MandataryNetwork.
        :type: str
        """

        self._siren = siren

    @property
    def siret(self):
        """
        Gets the siret of this MandataryNetwork.

        :return: The siret of this MandataryNetwork.
        :rtype: str
        """
        return self._siret

    @siret.setter
    def siret(self, siret):
        """
        Sets the siret of this MandataryNetwork.

        :param siret: The siret of this MandataryNetwork.
        :type: str
        """

        self._siret = siret

    @property
    def address(self):
        """
        Gets the address of this MandataryNetwork.

        :return: The address of this MandataryNetwork.
        :rtype: Address
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this MandataryNetwork.

        :param address: The address of this MandataryNetwork.
        :type: Address
        """

        self._address = address

    @property
    def phone(self):
        """
        Gets the phone of this MandataryNetwork.

        :return: The phone of this MandataryNetwork.
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """
        Sets the phone of this MandataryNetwork.

        :param phone: The phone of this MandataryNetwork.
        :type: str
        """

        self._phone = phone

    @property
    def email(self):
        """
        Gets the email of this MandataryNetwork.

        :return: The email of this MandataryNetwork.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this MandataryNetwork.

        :param email: The email of this MandataryNetwork.
        :type: str
        """

        self._email = email

    @property
    def url(self):
        """
        Gets the url of this MandataryNetwork.

        :return: The url of this MandataryNetwork.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this MandataryNetwork.

        :param url: The url of this MandataryNetwork.
        :type: str
        """

        self._url = url

    @property
    def image_url(self):
        """
        Gets the image_url of this MandataryNetwork.

        :return: The image_url of this MandataryNetwork.
        :rtype: str
        """
        return self._image_url

    @image_url.setter
    def image_url(self, image_url):
        """
        Sets the image_url of this MandataryNetwork.

        :param image_url: The image_url of this MandataryNetwork.
        :type: str
        """

        self._image_url = image_url

    @property
    def active(self):
        """
        Gets the active of this MandataryNetwork.

        :return: The active of this MandataryNetwork.
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """
        Sets the active of this MandataryNetwork.

        :param active: The active of this MandataryNetwork.
        :type: bool
        """

        self._active = active

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, MandataryNetwork):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.ad import Ad
from .models.ad_ref import AdRef
from .models.address import Address
from .models.agency import Agency
from .models.agency_naf_code import AgencyNafCode
from .models.body import Body
from .models.body_1 import Body1
from .models.body_2 import Body2
from .models.bound_type import BoundType
from .models.building import Building
from .models.city import City
from .models.count_response import CountResponse
from .models.crawl_source import CrawlSource
from .models.customer import Customer
from .models.date_histogram import DateHistogram
from .models.date_histogram_point import DateHistogramPoint
from .models.dealer_sub_type import DealerSubType
from .models.dealer_type import DealerType
from .models.default_response import DefaultResponse
from .models.event_type import EventType
from .models.histogram import Histogram
from .models.histogram_point import HistogramPoint
from .models.inline_response_200 import InlineResponse200
from .models.inline_response_200_1 import InlineResponse2001
from .models.inline_response_200_2 import InlineResponse2002
from .models.inline_response_200_3 import InlineResponse2003
from .models.inline_response_200_4 import InlineResponse2004
from .models.inline_response_200_5 import InlineResponse2005
from .models.inline_response_200_6 import InlineResponse2006
from .models.inline_response_200_7 import InlineResponse2007
from .models.iris_quarter import IrisQuarter
from .models.lng_lat import LngLat
from .models.location import Location
from .models.mandatary_network import MandataryNetwork
from .models.marketing_dealer import MarketingDealer
from .models.marketing_type import MarketingType
from .models.model_property import ModelProperty
from .models.percentiles import Percentiles
from .models.percentiles_values import PercentilesValues
from .models.price_event import PriceEvent
from .models.property_building import PropertyBuilding
from .models.property_features import PropertyFeatures
from .models.property_features_additional_features import PropertyFeaturesAdditionalFeatures
from .models.property_features_condominium import PropertyFeaturesCondominium
from .models.property_features_construction import PropertyFeaturesConstruction
from .models.property_features_descriptive import PropertyFeaturesDescriptive
from .models.property_features_descriptive_equipments import PropertyFeaturesDescriptiveEquipments
from .models.property_features_descriptive_services import PropertyFeaturesDescriptiveServices
from .models.property_features_energy import PropertyFeaturesEnergy
from .models.property_features_geometry import PropertyFeaturesGeometry
from .models.property_features_geometry_areas import PropertyFeaturesGeometryAreas
from .models.property_features_geometry_floors import PropertyFeaturesGeometryFloors
from .models.property_features_visual import PropertyFeaturesVisual
from .models.property_marketing import PropertyMarketing
from .models.property_search_query import PropertySearchQuery
from .models.property_type import PropertyType
from .models.range import Range
from .models.rent_control import RentControl
from .models.rent_control_result import RentControlResult
from .models.rent_control_status import RentControlStatus
from .models.rent_control_zone import RentControlZone
from .models.room import Room
from .models.search_query_param import SearchQueryParam
from .models.sections import Sections
from .models.sections_conclusion import SectionsConclusion
from .models.sections_estimation_engine import SectionsEstimationEngine
from .models.sections_estimation_engine_zones import SectionsEstimationEngineZones
from .models.sections_market_stats import SectionsMarketStats
from .models.sections_property_price_study import SectionsPropertyPriceStudy
from .models.sections_similar_properties import SectionsSimilarProperties
from .models.state import State
from .models.stats import Stats
from .models.stock_evolution import StockEvolution
from .models.stock_evolution_point import StockEvolutionPoint
from .models.study import Study
from .models.user import User
from .models.user_user_preference import UserUserPreference
from .models.user_user_preference_commercial_zone import UserUserPreferenceCommercialZone

# import apis into sdk package
from .apis.agences_api import AgencesApi
from .apis.annonces_api import AnnoncesApi
from .apis.biens_api import BiensApi
from .apis.bienssimilaires_api import BienssimilairesApi
from .apis.encadrementloyers_api import EncadrementloyersApi
from .apis.etudes_api import EtudesApi
from .apis.evenementsadbox_api import EvenementsadboxApi
from .apis.mandataires_api import MandatairesApi
from .apis.utilisateurs_api import UtilisateursApi
from .apis.villes_api import VillesApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class User(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'organization_id': 'int',
        'title': 'str',
        'username': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'mobile_phone_number': 'str',
        'office_phone_nuber': 'str',
        'avatar_url': 'str',
        'agencies': 'list[int]',
        'mandatary_network_id': 'int',
        'capsule_id': 'str',
        'creation_date': 'datetime',
        'active': 'bool',
        'admin': 'bool',
        'first_connection': 'bool',
        'user_preference': 'UserUserPreference',
        'hosts': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'organization_id': 'organizationId',
        'title': 'title',
        'username': 'username',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'email': 'email',
        'mobile_phone_number': 'mobilePhoneNumber',
        'office_phone_nuber': 'officePhoneNuber',
        'avatar_url': 'avatarUrl',
        'agencies': 'agencies',
        'mandatary_network_id': 'mandataryNetworkId',
        'capsule_id': 'capsuleId',
        'creation_date': 'creationDate',
        'active': 'active',
        'admin': 'admin',
        'first_connection': 'firstConnection',
        'user_preference': 'userPreference',
        'hosts': 'hosts'
    }

    def __init__(self, id=None, organization_id=None, title=None, username=None, first_name=None, last_name=None, email=None, mobile_phone_number=None, office_phone_nuber=None, avatar_url=None, agencies=None, mandatary_network_id=None, capsule_id=None, creation_date=None, active=None, admin=None, first_connection=None, user_preference=None, hosts=None):
        """
        User - a model defined in Swagger
        """

        self._id = None
        self._organization_id = None
        self._title = None
        self._username = None
        self._first_name = None
        self._last_name = None
        self._email = None
        self._mobile_phone_number = None
        self._office_phone_nuber = None
        self._avatar_url = None
        self._agencies = None
        self._mandatary_network_id = None
        self._capsule_id = None
        self._creation_date = None
        self._active = None
        self._admin = None
        self._first_connection = None
        self._user_preference = None
        self._hosts = None

        if id is not None:
          self.id = id
        if organization_id is not None:
          self.organization_id = organization_id
        if title is not None:
          self.title = title
        if username is not None:
          self.username = username
        if first_name is not None:
          self.first_name = first_name
        if last_name is not None:
          self.last_name = last_name
        if email is not None:
          self.email = email
        if mobile_phone_number is not None:
          self.mobile_phone_number = mobile_phone_number
        if office_phone_nuber is not None:
          self.office_phone_nuber = office_phone_nuber
        if avatar_url is not None:
          self.avatar_url = avatar_url
        if agencies is not None:
          self.agencies = agencies
        if mandatary_network_id is not None:
          self.mandatary_network_id = mandatary_network_id
        if capsule_id is not None:
          self.capsule_id = capsule_id
        if creation_date is not None:
          self.creation_date = creation_date
        if active is not None:
          self.active = active
        if admin is not None:
          self.admin = admin
        if first_connection is not None:
          self.first_connection = first_connection
        if user_preference is not None:
          self.user_preference = user_preference
        if hosts is not None:
          self.hosts = hosts

    @property
    def id(self):
        """
        Gets the id of this User.

        :return: The id of this User.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this User.

        :param id: The id of this User.
        :type: int
        """

        self._id = id

    @property
    def organization_id(self):
        """
        Gets the organization_id of this User.

        :return: The organization_id of this User.
        :rtype: int
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """
        Sets the organization_id of this User.

        :param organization_id: The organization_id of this User.
        :type: int
        """

        self._organization_id = organization_id

    @property
    def title(self):
        """
        Gets the title of this User.

        :return: The title of this User.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this User.

        :param title: The title of this User.
        :type: str
        """
        allowed_values = ["MR", "MRS"]
        if title not in allowed_values:
            raise ValueError(
                "Invalid value for `title` ({0}), must be one of {1}"
                .format(title, allowed_values)
            )

        self._title = title

    @property
    def username(self):
        """
        Gets the username of this User.

        :return: The username of this User.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this User.

        :param username: The username of this User.
        :type: str
        """

        self._username = username

    @property
    def first_name(self):
        """
        Gets the first_name of this User.

        :return: The first_name of this User.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this User.

        :param first_name: The first_name of this User.
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this User.

        :return: The last_name of this User.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this User.

        :param last_name: The last_name of this User.
        :type: str
        """

        self._last_name = last_name

    @property
    def email(self):
        """
        Gets the email of this User.

        :return: The email of this User.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this User.

        :param email: The email of this User.
        :type: str
        """

        self._email = email

    @property
    def mobile_phone_number(self):
        """
        Gets the mobile_phone_number of this User.

        :return: The mobile_phone_number of this User.
        :rtype: str
        """
        return self._mobile_phone_number

    @mobile_phone_number.setter
    def mobile_phone_number(self, mobile_phone_number):
        """
        Sets the mobile_phone_number of this User.

        :param mobile_phone_number: The mobile_phone_number of this User.
        :type: str
        """

        self._mobile_phone_number = mobile_phone_number

    @property
    def office_phone_nuber(self):
        """
        Gets the office_phone_nuber of this User.

        :return: The office_phone_nuber of this User.
        :rtype: str
        """
        return self._office_phone_nuber

    @office_phone_nuber.setter
    def office_phone_nuber(self, office_phone_nuber):
        """
        Sets the office_phone_nuber of this User.

        :param office_phone_nuber: The office_phone_nuber of this User.
        :type: str
        """

        self._office_phone_nuber = office_phone_nuber

    @property
    def avatar_url(self):
        """
        Gets the avatar_url of this User.

        :return: The avatar_url of this User.
        :rtype: str
        """
        return self._avatar_url

    @avatar_url.setter
    def avatar_url(self, avatar_url):
        """
        Sets the avatar_url of this User.

        :param avatar_url: The avatar_url of this User.
        :type: str
        """

        self._avatar_url = avatar_url

    @property
    def agencies(self):
        """
        Gets the agencies of this User.

        :return: The agencies of this User.
        :rtype: list[int]
        """
        return self._agencies

    @agencies.setter
    def agencies(self, agencies):
        """
        Sets the agencies of this User.

        :param agencies: The agencies of this User.
        :type: list[int]
        """

        self._agencies = agencies

    @property
    def mandatary_network_id(self):
        """
        Gets the mandatary_network_id of this User.

        :return: The mandatary_network_id of this User.
        :rtype: int
        """
        return self._mandatary_network_id

    @mandatary_network_id.setter
    def mandatary_network_id(self, mandatary_network_id):
        """
        Sets the mandatary_network_id of this User.

        :param mandatary_network_id: The mandatary_network_id of this User.
        :type: int
        """

        self._mandatary_network_id = mandatary_network_id

    @property
    def capsule_id(self):
        """
        Gets the capsule_id of this User.

        :return: The capsule_id of this User.
        :rtype: str
        """
        return self._capsule_id

    @capsule_id.setter
    def capsule_id(self, capsule_id):
        """
        Sets the capsule_id of this User.

        :param capsule_id: The capsule_id of this User.
        :type: str
        """

        self._capsule_id = capsule_id

    @property
    def creation_date(self):
        """
        Gets the creation_date of this User.

        :return: The creation_date of this User.
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """
        Sets the creation_date of this User.

        :param creation_date: The creation_date of this User.
        :type: datetime
        """

        self._creation_date = creation_date

    @property
    def active(self):
        """
        Gets the active of this User.

        :return: The active of this User.
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """
        Sets the active of this User.

        :param active: The active of this User.
        :type: bool
        """

        self._active = active

    @property
    def admin(self):
        """
        Gets the admin of this User.

        :return: The admin of this User.
        :rtype: bool
        """
        return self._admin

    @admin.setter
    def admin(self, admin):
        """
        Sets the admin of this User.

        :param admin: The admin of this User.
        :type: bool
        """

        self._admin = admin

    @property
    def first_connection(self):
        """
        Gets the first_connection of this User.

        :return: The first_connection of this User.
        :rtype: bool
        """
        return self._first_connection

    @first_connection.setter
    def first_connection(self, first_connection):
        """
        Sets the first_connection of this User.

        :param first_connection: The first_connection of this User.
        :type: bool
        """

        self._first_connection = first_connection

    @property
    def user_preference(self):
        """
        Gets the user_preference of this User.

        :return: The user_preference of this User.
        :rtype: UserUserPreference
        """
        return self._user_preference

    @user_preference.setter
    def user_preference(self, user_preference):
        """
        Sets the user_preference of this User.

        :param user_preference: The user_preference of this User.
        :type: UserUserPreference
        """

        self._user_preference = user_preference

    @property
    def hosts(self):
        """
        Gets the hosts of this User.

        :return: The hosts of this User.
        :rtype: list[str]
        """
        return self._hosts

    @hosts.setter
    def hosts(self, hosts):
        """
        Sets the hosts of this User.

        :param hosts: The hosts of this User.
        :type: list[str]
        """

        self._hosts = hosts

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, User):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PropertySearchQuery(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'search_query_param': 'SearchQueryParam',
        'query_string': 'str',
        'marketing_types': 'list[MarketingType]',
        'crawl_sources': 'list[CrawlSource]',
        'active': 'bool',
        'dealer_types': 'list[DealerType]',
        'dealer_names': 'list[str]',
        'exclusive_mandate': 'bool',
        'dealer_ids': 'int',
        'excluded_dealer_ids': 'list[int]',
        'property_ids': 'list[str]',
        'property_types': 'list[PropertyType]',
        'room_counts': 'list[int]',
        'departments': 'list[str]',
        'zip_codes': 'list[str]',
        'city_ids': 'list[int]',
        'publication_date_min': 'datetime',
        'publication_date_max': 'datetime',
        'ad_publication_date_min': 'datetime',
        'ad_publication_date_max': 'datetime',
        'last_price_decrease_date_min': 'datetime',
        'last_price_decrease_date_max': 'datetime',
        'delete_date_min': 'datetime',
        'delete_date_max': 'datetime',
        'duration_days_min': 'int',
        'duration_days_max': 'int',
        'surface_min': 'float',
        'surface_max': 'float',
        'price_min': 'float',
        'price_max': 'float',
        'price_m2_min': 'float',
        'price_m2_max': 'float',
        'price_hc_min': 'float',
        'price_hc_max': 'float',
        'price_m2_hc_min': 'float',
        'price_m2_hc_max': 'float',
        'price_cc_min': 'float',
        'price_cc_max': 'float',
        'fees_min': 'float',
        'fees_max': 'float',
        'deposit_min': 'float',
        'deposit_max': 'float',
        'furnished': 'bool',
        'new_build': 'bool',
        'missing_fields': 'list[str]',
        'excluded_ids': 'list[str]'
    }

    attribute_map = {
        'search_query_param': 'searchQueryParam',
        'query_string': 'queryString',
        'marketing_types': 'marketingTypes',
        'crawl_sources': 'crawlSources',
        'active': 'active',
        'dealer_types': 'dealerTypes',
        'dealer_names': 'dealerNames',
        'exclusive_mandate': 'exclusiveMandate',
        'dealer_ids': 'dealerIds',
        'excluded_dealer_ids': 'excludedDealerIds',
        'property_ids': 'propertyIds',
        'property_types': 'propertyTypes',
        'room_counts': 'roomCounts',
        'departments': 'departments',
        'zip_codes': 'zipCodes',
        'city_ids': 'cityIds',
        'publication_date_min': 'publicationDateMin',
        'publication_date_max': 'publicationDateMax',
        'ad_publication_date_min': 'adPublicationDateMin',
        'ad_publication_date_max': 'adPublicationDateMax',
        'last_price_decrease_date_min': 'lastPriceDecreaseDateMin',
        'last_price_decrease_date_max': 'lastPriceDecreaseDateMax',
        'delete_date_min': 'deleteDateMin',
        'delete_date_max': 'deleteDateMax',
        'duration_days_min': 'durationDaysMin',
        'duration_days_max': 'durationDaysMax',
        'surface_min': 'surfaceMin',
        'surface_max': 'surfaceMax',
        'price_min': 'priceMin',
        'price_max': 'priceMax',
        'price_m2_min': 'priceM2Min',
        'price_m2_max': 'priceM2Max',
        'price_hc_min': 'priceHCMin',
        'price_hc_max': 'priceHCMax',
        'price_m2_hc_min': 'priceM2HCMin',
        'price_m2_hc_max': 'priceM2HCMax',
        'price_cc_min': 'priceCCMin',
        'price_cc_max': 'priceCCMax',
        'fees_min': 'feesMin',
        'fees_max': 'feesMax',
        'deposit_min': 'depositMin',
        'deposit_max': 'depositMax',
        'furnished': 'furnished',
        'new_build': 'newBuild',
        'missing_fields': 'missingFields',
        'excluded_ids': 'excludedIds'
    }

    def __init__(self, search_query_param=None, query_string=None, marketing_types=None, crawl_sources=None, active=None, dealer_types=None, dealer_names=None, exclusive_mandate=None, dealer_ids=None, excluded_dealer_ids=None, property_ids=None, property_types=None, room_counts=None, departments=None, zip_codes=None, city_ids=None, publication_date_min=None, publication_date_max=None, ad_publication_date_min=None, ad_publication_date_max=None, last_price_decrease_date_min=None, last_price_decrease_date_max=None, delete_date_min=None, delete_date_max=None, duration_days_min=None, duration_days_max=None, surface_min=None, surface_max=None, price_min=None, price_max=None, price_m2_min=None, price_m2_max=None, price_hc_min=None, price_hc_max=None, price_m2_hc_min=None, price_m2_hc_max=None, price_cc_min=None, price_cc_max=None, fees_min=None, fees_max=None, deposit_min=None, deposit_max=None, furnished=None, new_build=None, missing_fields=None, excluded_ids=None):
        """
        PropertySearchQuery - a model defined in Swagger
        """

        self._search_query_param = None
        self._query_string = None
        self._marketing_types = None
        self._crawl_sources = None
        self._active = None
        self._dealer_types = None
        self._dealer_names = None
        self._exclusive_mandate = None
        self._dealer_ids = None
        self._excluded_dealer_ids = None
        self._property_ids = None
        self._property_types = None
        self._room_counts = None
        self._departments = None
        self._zip_codes = None
        self._city_ids = None
        self._publication_date_min = None
        self._publication_date_max = None
        self._ad_publication_date_min = None
        self._ad_publication_date_max = None
        self._last_price_decrease_date_min = None
        self._last_price_decrease_date_max = None
        self._delete_date_min = None
        self._delete_date_max = None
        self._duration_days_min = None
        self._duration_days_max = None
        self._surface_min = None
        self._surface_max = None
        self._price_min = None
        self._price_max = None
        self._price_m2_min = None
        self._price_m2_max = None
        self._price_hc_min = None
        self._price_hc_max = None
        self._price_m2_hc_min = None
        self._price_m2_hc_max = None
        self._price_cc_min = None
        self._price_cc_max = None
        self._fees_min = None
        self._fees_max = None
        self._deposit_min = None
        self._deposit_max = None
        self._furnished = None
        self._new_build = None
        self._missing_fields = None
        self._excluded_ids = None

        if search_query_param is not None:
          self.search_query_param = search_query_param
        if query_string is not None:
          self.query_string = query_string
        if marketing_types is not None:
          self.marketing_types = marketing_types
        if crawl_sources is not None:
          self.crawl_sources = crawl_sources
        if active is not None:
          self.active = active
        if dealer_types is not None:
          self.dealer_types = dealer_types
        if dealer_names is not None:
          self.dealer_names = dealer_names
        if exclusive_mandate is not None:
          self.exclusive_mandate = exclusive_mandate
        if dealer_ids is not None:
          self.dealer_ids = dealer_ids
        if excluded_dealer_ids is not None:
          self.excluded_dealer_ids = excluded_dealer_ids
        if property_ids is not None:
          self.property_ids = property_ids
        if property_types is not None:
          self.property_types = property_types
        if room_counts is not None:
          self.room_counts = room_counts
        if departments is not None:
          self.departments = departments
        if zip_codes is not None:
          self.zip_codes = zip_codes
        if city_ids is not None:
          self.city_ids = city_ids
        if publication_date_min is not None:
          self.publication_date_min = publication_date_min
        if publication_date_max is not None:
          self.publication_date_max = publication_date_max
        if ad_publication_date_min is not None:
          self.ad_publication_date_min = ad_publication_date_min
        if ad_publication_date_max is not None:
          self.ad_publication_date_max = ad_publication_date_max
        if last_price_decrease_date_min is not None:
          self.last_price_decrease_date_min = last_price_decrease_date_min
        if last_price_decrease_date_max is not None:
          self.last_price_decrease_date_max = last_price_decrease_date_max
        if delete_date_min is not None:
          self.delete_date_min = delete_date_min
        if delete_date_max is not None:
          self.delete_date_max = delete_date_max
        if duration_days_min is not None:
          self.duration_days_min = duration_days_min
        if duration_days_max is not None:
          self.duration_days_max = duration_days_max
        if surface_min is not None:
          self.surface_min = surface_min
        if surface_max is not None:
          self.surface_max = surface_max
        if price_min is not None:
          self.price_min = price_min
        if price_max is not None:
          self.price_max = price_max
        if price_m2_min is not None:
          self.price_m2_min = price_m2_min
        if price_m2_max is not None:
          self.price_m2_max = price_m2_max
        if price_hc_min is not None:
          self.price_hc_min = price_hc_min
        if price_hc_max is not None:
          self.price_hc_max = price_hc_max
        if price_m2_hc_min is not None:
          self.price_m2_hc_min = price_m2_hc_min
        if price_m2_hc_max is not None:
          self.price_m2_hc_max = price_m2_hc_max
        if price_cc_min is not None:
          self.price_cc_min = price_cc_min
        if price_cc_max is not None:
          self.price_cc_max = price_cc_max
        if fees_min is not None:
          self.fees_min = fees_min
        if fees_max is not None:
          self.fees_max = fees_max
        if deposit_min is not None:
          self.deposit_min = deposit_min
        if deposit_max is not None:
          self.deposit_max = deposit_max
        if furnished is not None:
          self.furnished = furnished
        if new_build is not None:
          self.new_build = new_build
        if missing_fields is not None:
          self.missing_fields = missing_fields
        if excluded_ids is not None:
          self.excluded_ids = excluded_ids

    @property
    def search_query_param(self):
        """
        Gets the search_query_param of this PropertySearchQuery.

        :return: The search_query_param of this PropertySearchQuery.
        :rtype: SearchQueryParam
        """
        return self._search_query_param

    @search_query_param.setter
    def search_query_param(self, search_query_param):
        """
        Sets the search_query_param of this PropertySearchQuery.

        :param search_query_param: The search_query_param of this PropertySearchQuery.
        :type: SearchQueryParam
        """

        self._search_query_param = search_query_param

    @property
    def query_string(self):
        """
        Gets the query_string of this PropertySearchQuery.

        :return: The query_string of this PropertySearchQuery.
        :rtype: str
        """
        return self._query_string

    @query_string.setter
    def query_string(self, query_string):
        """
        Sets the query_string of this PropertySearchQuery.

        :param query_string: The query_string of this PropertySearchQuery.
        :type: str
        """

        self._query_string = query_string

    @property
    def marketing_types(self):
        """
        Gets the marketing_types of this PropertySearchQuery.

        :return: The marketing_types of this PropertySearchQuery.
        :rtype: list[MarketingType]
        """
        return self._marketing_types

    @marketing_types.setter
    def marketing_types(self, marketing_types):
        """
        Sets the marketing_types of this PropertySearchQuery.

        :param marketing_types: The marketing_types of this PropertySearchQuery.
        :type: list[MarketingType]
        """

        self._marketing_types = marketing_types

    @property
    def crawl_sources(self):
        """
        Gets the crawl_sources of this PropertySearchQuery.

        :return: The crawl_sources of this PropertySearchQuery.
        :rtype: list[CrawlSource]
        """
        return self._crawl_sources

    @crawl_sources.setter
    def crawl_sources(self, crawl_sources):
        """
        Sets the crawl_sources of this PropertySearchQuery.

        :param crawl_sources: The crawl_sources of this PropertySearchQuery.
        :type: list[CrawlSource]
        """

        self._crawl_sources = crawl_sources

    @property
    def active(self):
        """
        Gets the active of this PropertySearchQuery.

        :return: The active of this PropertySearchQuery.
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """
        Sets the active of this PropertySearchQuery.

        :param active: The active of this PropertySearchQuery.
        :type: bool
        """

        self._active = active

    @property
    def dealer_types(self):
        """
        Gets the dealer_types of this PropertySearchQuery.

        :return: The dealer_types of this PropertySearchQuery.
        :rtype: list[DealerType]
        """
        return self._dealer_types

    @dealer_types.setter
    def dealer_types(self, dealer_types):
        """
        Sets the dealer_types of this PropertySearchQuery.

        :param dealer_types: The dealer_types of this PropertySearchQuery.
        :type: list[DealerType]
        """

        self._dealer_types = dealer_types

    @property
    def dealer_names(self):
        """
        Gets the dealer_names of this PropertySearchQuery.

        :return: The dealer_names of this PropertySearchQuery.
        :rtype: list[str]
        """
        return self._dealer_names

    @dealer_names.setter
    def dealer_names(self, dealer_names):
        """
        Sets the dealer_names of this PropertySearchQuery.

        :param dealer_names: The dealer_names of this PropertySearchQuery.
        :type: list[str]
        """

        self._dealer_names = dealer_names

    @property
    def exclusive_mandate(self):
        """
        Gets the exclusive_mandate of this PropertySearchQuery.

        :return: The exclusive_mandate of this PropertySearchQuery.
        :rtype: bool
        """
        return self._exclusive_mandate

    @exclusive_mandate.setter
    def exclusive_mandate(self, exclusive_mandate):
        """
        Sets the exclusive_mandate of this PropertySearchQuery.

        :param exclusive_mandate: The exclusive_mandate of this PropertySearchQuery.
        :type: bool
        """

        self._exclusive_mandate = exclusive_mandate

    @property
    def dealer_ids(self):
        """
        Gets the dealer_ids of this PropertySearchQuery.

        :return: The dealer_ids of this PropertySearchQuery.
        :rtype: int
        """
        return self._dealer_ids

    @dealer_ids.setter
    def dealer_ids(self, dealer_ids):
        """
        Sets the dealer_ids of this PropertySearchQuery.

        :param dealer_ids: The dealer_ids of this PropertySearchQuery.
        :type: int
        """

        self._dealer_ids = dealer_ids

    @property
    def excluded_dealer_ids(self):
        """
        Gets the excluded_dealer_ids of this PropertySearchQuery.

        :return: The excluded_dealer_ids of this PropertySearchQuery.
        :rtype: list[int]
        """
        return self._excluded_dealer_ids

    @excluded_dealer_ids.setter
    def excluded_dealer_ids(self, excluded_dealer_ids):
        """
        Sets the excluded_dealer_ids of this PropertySearchQuery.

        :param excluded_dealer_ids: The excluded_dealer_ids of this PropertySearchQuery.
        :type: list[int]
        """

        self._excluded_dealer_ids = excluded_dealer_ids

    @property
    def property_ids(self):
        """
        Gets the property_ids of this PropertySearchQuery.

        :return: The property_ids of this PropertySearchQuery.
        :rtype: list[str]
        """
        return self._property_ids

    @property_ids.setter
    def property_ids(self, property_ids):
        """
        Sets the property_ids of this PropertySearchQuery.

        :param property_ids: The property_ids of this PropertySearchQuery.
        :type: list[str]
        """

        self._property_ids = property_ids

    @property
    def property_types(self):
        """
        Gets the property_types of this PropertySearchQuery.

        :return: The property_types of this PropertySearchQuery.
        :rtype: list[PropertyType]
        """
        return self._property_types

    @property_types.setter
    def property_types(self, property_types):
        """
        Sets the property_types of this PropertySearchQuery.

        :param property_types: The property_types of this PropertySearchQuery.
        :type: list[PropertyType]
        """

        self._property_types = property_types

    @property
    def room_counts(self):
        """
        Gets the room_counts of this PropertySearchQuery.

        :return: The room_counts of this PropertySearchQuery.
        :rtype: list[int]
        """
        return self._room_counts

    @room_counts.setter
    def room_counts(self, room_counts):
        """
        Sets the room_counts of this PropertySearchQuery.

        :param room_counts: The room_counts of this PropertySearchQuery.
        :type: list[int]
        """

        self._room_counts = room_counts

    @property
    def departments(self):
        """
        Gets the departments of this PropertySearchQuery.

        :return: The departments of this PropertySearchQuery.
        :rtype: list[str]
        """
        return self._departments

    @departments.setter
    def departments(self, departments):
        """
        Sets the departments of this PropertySearchQuery.

        :param departments: The departments of this PropertySearchQuery.
        :type: list[str]
        """

        self._departments = departments

    @property
    def zip_codes(self):
        """
        Gets the zip_codes of this PropertySearchQuery.

        :return: The zip_codes of this PropertySearchQuery.
        :rtype: list[str]
        """
        return self._zip_codes

    @zip_codes.setter
    def zip_codes(self, zip_codes):
        """
        Sets the zip_codes of this PropertySearchQuery.

        :param zip_codes: The zip_codes of this PropertySearchQuery.
        :type: list[str]
        """

        self._zip_codes = zip_codes

    @property
    def city_ids(self):
        """
        Gets the city_ids of this PropertySearchQuery.

        :return: The city_ids of this PropertySearchQuery.
        :rtype: list[int]
        """
        return self._city_ids

    @city_ids.setter
    def city_ids(self, city_ids):
        """
        Sets the city_ids of this PropertySearchQuery.

        :param city_ids: The city_ids of this PropertySearchQuery.
        :type: list[int]
        """

        self._city_ids = city_ids

    @property
    def publication_date_min(self):
        """
        Gets the publication_date_min of this PropertySearchQuery.

        :return: The publication_date_min of this PropertySearchQuery.
        :rtype: datetime
        """
        return self._publication_date_min

    @publication_date_min.setter
    def publication_date_min(self, publication_date_min):
        """
        Sets the publication_date_min of this PropertySearchQuery.

        :param publication_date_min: The publication_date_min of this PropertySearchQuery.
        :type: datetime
        """

        self._publication_date_min = publication_date_min

    @property
    def publication_date_max(self):
        """
        Gets the publication_date_max of this PropertySearchQuery.

        :return: The publication_date_max of this PropertySearchQuery.
        :rtype: datetime
        """
        return self._publication_date_max

    @publication_date_max.setter
    def publication_date_max(self, publication_date_max):
        """
        Sets the publication_date_max of this PropertySearchQuery.

        :param publication_date_max: The publication_date_max of this PropertySearchQuery.
        :type: datetime
        """

        self._publication_date_max = publication_date_max

    @property
    def ad_publication_date_min(self):
        """
        Gets the ad_publication_date_min of this PropertySearchQuery.

        :return: The ad_publication_date_min of this PropertySearchQuery.
        :rtype: datetime
        """
        return self._ad_publication_date_min

    @ad_publication_date_min.setter
    def ad_publication_date_min(self, ad_publication_date_min):
        """
        Sets the ad_publication_date_min of this PropertySearchQuery.

        :param ad_publication_date_min: The ad_publication_date_min of this PropertySearchQuery.
        :type: datetime
        """

        self._ad_publication_date_min = ad_publication_date_min

    @property
    def ad_publication_date_max(self):
        """
        Gets the ad_publication_date_max of this PropertySearchQuery.

        :return: The ad_publication_date_max of this PropertySearchQuery.
        :rtype: datetime
        """
        return self._ad_publication_date_max

    @ad_publication_date_max.setter
    def ad_publication_date_max(self, ad_publication_date_max):
        """
        Sets the ad_publication_date_max of this PropertySearchQuery.

        :param ad_publication_date_max: The ad_publication_date_max of this PropertySearchQuery.
        :type: datetime
        """

        self._ad_publication_date_max = ad_publication_date_max

    @property
    def last_price_decrease_date_min(self):
        """
        Gets the last_price_decrease_date_min of this PropertySearchQuery.

        :return: The last_price_decrease_date_min of this PropertySearchQuery.
        :rtype: datetime
        """
        return self._last_price_decrease_date_min

    @last_price_decrease_date_min.setter
    def last_price_decrease_date_min(self, last_price_decrease_date_min):
        """
        Sets the last_price_decrease_date_min of this PropertySearchQuery.

        :param last_price_decrease_date_min: The last_price_decrease_date_min of this PropertySearchQuery.
        :type: datetime
        """

        self._last_price_decrease_date_min = last_price_decrease_date_min

    @property
    def last_price_decrease_date_max(self):
        """
        Gets the last_price_decrease_date_max of this PropertySearchQuery.

        :return: The last_price_decrease_date_max of this PropertySearchQuery.
        :rtype: datetime
        """
        return self._last_price_decrease_date_max

    @last_price_decrease_date_max.setter
    def last_price_decrease_date_max(self, last_price_decrease_date_max):
        """
        Sets the last_price_decrease_date_max of this PropertySearchQuery.

        :param last_price_decrease_date_max: The last_price_decrease_date_max of this PropertySearchQuery.
        :type: datetime
        """

        self._last_price_decrease_date_max = last_price_decrease_date_max

    @property
    def delete_date_min(self):
        """
        Gets the delete_date_min of this PropertySearchQuery.

        :return: The delete_date_min of this PropertySearchQuery.
        :rtype: datetime
        """
        return self._delete_date_min

    @delete_date_min.setter
    def delete_date_min(self, delete_date_min):
        """
        Sets the delete_date_min of this PropertySearchQuery.

        :param delete_date_min: The delete_date_min of this PropertySearchQuery.
        :type: datetime
        """

        self._delete_date_min = delete_date_min

    @property
    def delete_date_max(self):
        """
        Gets the delete_date_max of this PropertySearchQuery.

        :return: The delete_date_max of this PropertySearchQuery.
        :rtype: datetime
        """
        return self._delete_date_max

    @delete_date_max.setter
    def delete_date_max(self, delete_date_max):
        """
        Sets the delete_date_max of this PropertySearchQuery.

        :param delete_date_max: The delete_date_max of this PropertySearchQuery.
        :type: datetime
        """

        self._delete_date_max = delete_date_max

    @property
    def duration_days_min(self):
        """
        Gets the duration_days_min of this PropertySearchQuery.

        :return: The duration_days_min of this PropertySearchQuery.
        :rtype: int
        """
        return self._duration_days_min

    @duration_days_min.setter
    def duration_days_min(self, duration_days_min):
        """
        Sets the duration_days_min of this PropertySearchQuery.

        :param duration_days_min: The duration_days_min of this PropertySearchQuery.
        :type: int
        """

        self._duration_days_min = duration_days_min

    @property
    def duration_days_max(self):
        """
        Gets the duration_days_max of this PropertySearchQuery.

        :return: The duration_days_max of this PropertySearchQuery.
        :rtype: int
        """
        return self._duration_days_max

    @duration_days_max.setter
    def duration_days_max(self, duration_days_max):
        """
        Sets the duration_days_max of this PropertySearchQuery.

        :param duration_days_max: The duration_days_max of this PropertySearchQuery.
        :type: int
        """

        self._duration_days_max = duration_days_max

    @property
    def surface_min(self):
        """
        Gets the surface_min of this PropertySearchQuery.

        :return: The surface_min of this PropertySearchQuery.
        :rtype: float
        """
        return self._surface_min

    @surface_min.setter
    def surface_min(self, surface_min):
        """
        Sets the surface_min of this PropertySearchQuery.

        :param surface_min: The surface_min of this PropertySearchQuery.
        :type: float
        """

        self._surface_min = surface_min

    @property
    def surface_max(self):
        """
        Gets the surface_max of this PropertySearchQuery.

        :return: The surface_max of this PropertySearchQuery.
        :rtype: float
        """
        return self._surface_max

    @surface_max.setter
    def surface_max(self, surface_max):
        """
        Sets the surface_max of this PropertySearchQuery.

        :param surface_max: The surface_max of this PropertySearchQuery.
        :type: float
        """

        self._surface_max = surface_max

    @property
    def price_min(self):
        """
        Gets the price_min of this PropertySearchQuery.

        :return: The price_min of this PropertySearchQuery.
        :rtype: float
        """
        return self._price_min

    @price_min.setter
    def price_min(self, price_min):
        """
        Sets the price_min of this PropertySearchQuery.

        :param price_min: The price_min of this PropertySearchQuery.
        :type: float
        """

        self._price_min = price_min

    @property
    def price_max(self):
        """
        Gets the price_max of this PropertySearchQuery.

        :return: The price_max of this PropertySearchQuery.
        :rtype: float
        """
        return self._price_max

    @price_max.setter
    def price_max(self, price_max):
        """
        Sets the price_max of this PropertySearchQuery.

        :param price_max: The price_max of this PropertySearchQuery.
        :type: float
        """

        self._price_max = price_max

    @property
    def price_m2_min(self):
        """
        Gets the price_m2_min of this PropertySearchQuery.

        :return: The price_m2_min of this PropertySearchQuery.
        :rtype: float
        """
        return self._price_m2_min

    @price_m2_min.setter
    def price_m2_min(self, price_m2_min):
        """
        Sets the price_m2_min of this PropertySearchQuery.

        :param price_m2_min: The price_m2_min of this PropertySearchQuery.
        :type: float
        """

        self._price_m2_min = price_m2_min

    @property
    def price_m2_max(self):
        """
        Gets the price_m2_max of this PropertySearchQuery.

        :return: The price_m2_max of this PropertySearchQuery.
        :rtype: float
        """
        return self._price_m2_max

    @price_m2_max.setter
    def price_m2_max(self, price_m2_max):
        """
        Sets the price_m2_max of this PropertySearchQuery.

        :param price_m2_max: The price_m2_max of this PropertySearchQuery.
        :type: float
        """

        self._price_m2_max = price_m2_max

    @property
    def price_hc_min(self):
        """
        Gets the price_hc_min of this PropertySearchQuery.

        :return: The price_hc_min of this PropertySearchQuery.
        :rtype: float
        """
        return self._price_hc_min

    @price_hc_min.setter
    def price_hc_min(self, price_hc_min):
        """
        Sets the price_hc_min of this PropertySearchQuery.

        :param price_hc_min: The price_hc_min of this PropertySearchQuery.
        :type: float
        """

        self._price_hc_min = price_hc_min

    @property
    def price_hc_max(self):
        """
        Gets the price_hc_max of this PropertySearchQuery.

        :return: The price_hc_max of this PropertySearchQuery.
        :rtype: float
        """
        return self._price_hc_max

    @price_hc_max.setter
    def price_hc_max(self, price_hc_max):
        """
        Sets the price_hc_max of this PropertySearchQuery.

        :param price_hc_max: The price_hc_max of this PropertySearchQuery.
        :type: float
        """

        self._price_hc_max = price_hc_max

    @property
    def price_m2_hc_min(self):
        """
        Gets the price_m2_hc_min of this PropertySearchQuery.

        :return: The price_m2_hc_min of this PropertySearchQuery.
        :rtype: float
        """
        return self._price_m2_hc_min

    @price_m2_hc_min.setter
    def price_m2_hc_min(self, price_m2_hc_min):
        """
        Sets the price_m2_hc_min of this PropertySearchQuery.

        :param price_m2_hc_min: The price_m2_hc_min of this PropertySearchQuery.
        :type: float
        """

        self._price_m2_hc_min = price_m2_hc_min

    @property
    def price_m2_hc_max(self):
        """
        Gets the price_m2_hc_max of this PropertySearchQuery.

        :return: The price_m2_hc_max of this PropertySearchQuery.
        :rtype: float
        """
        return self._price_m2_hc_max

    @price_m2_hc_max.setter
    def price_m2_hc_max(self, price_m2_hc_max):
        """
        Sets the price_m2_hc_max of this PropertySearchQuery.

        :param price_m2_hc_max: The price_m2_hc_max of this PropertySearchQuery.
        :type: float
        """

        self._price_m2_hc_max = price_m2_hc_max

    @property
    def price_cc_min(self):
        """
        Gets the price_cc_min of this PropertySearchQuery.

        :return: The price_cc_min of this PropertySearchQuery.
        :rtype: float
        """
        return self._price_cc_min

    @price_cc_min.setter
    def price_cc_min(self, price_cc_min):
        """
        Sets the price_cc_min of this PropertySearchQuery.

        :param price_cc_min: The price_cc_min of this PropertySearchQuery.
        :type: float
        """

        self._price_cc_min = price_cc_min

    @property
    def price_cc_max(self):
        """
        Gets the price_cc_max of this PropertySearchQuery.

        :return: The price_cc_max of this PropertySearchQuery.
        :rtype: float
        """
        return self._price_cc_max

    @price_cc_max.setter
    def price_cc_max(self, price_cc_max):
        """
        Sets the price_cc_max of this PropertySearchQuery.

        :param price_cc_max: The price_cc_max of this PropertySearchQuery.
        :type: float
        """

        self._price_cc_max = price_cc_max

    @property
    def fees_min(self):
        """
        Gets the fees_min of this PropertySearchQuery.

        :return: The fees_min of this PropertySearchQuery.
        :rtype: float
        """
        return self._fees_min

    @fees_min.setter
    def fees_min(self, fees_min):
        """
        Sets the fees_min of this PropertySearchQuery.

        :param fees_min: The fees_min of this PropertySearchQuery.
        :type: float
        """

        self._fees_min = fees_min

    @property
    def fees_max(self):
        """
        Gets the fees_max of this PropertySearchQuery.

        :return: The fees_max of this PropertySearchQuery.
        :rtype: float
        """
        return self._fees_max

    @fees_max.setter
    def fees_max(self, fees_max):
        """
        Sets the fees_max of this PropertySearchQuery.

        :param fees_max: The fees_max of this PropertySearchQuery.
        :type: float
        """

        self._fees_max = fees_max

    @property
    def deposit_min(self):
        """
        Gets the deposit_min of this PropertySearchQuery.

        :return: The deposit_min of this PropertySearchQuery.
        :rtype: float
        """
        return self._deposit_min

    @deposit_min.setter
    def deposit_min(self, deposit_min):
        """
        Sets the deposit_min of this PropertySearchQuery.

        :param deposit_min: The deposit_min of this PropertySearchQuery.
        :type: float
        """

        self._deposit_min = deposit_min

    @property
    def deposit_max(self):
        """
        Gets the deposit_max of this PropertySearchQuery.

        :return: The deposit_max of this PropertySearchQuery.
        :rtype: float
        """
        return self._deposit_max

    @deposit_max.setter
    def deposit_max(self, deposit_max):
        """
        Sets the deposit_max of this PropertySearchQuery.

        :param deposit_max: The deposit_max of this PropertySearchQuery.
        :type: float
        """

        self._deposit_max = deposit_max

    @property
    def furnished(self):
        """
        Gets the furnished of this PropertySearchQuery.

        :return: The furnished of this PropertySearchQuery.
        :rtype: bool
        """
        return self._furnished

    @furnished.setter
    def furnished(self, furnished):
        """
        Sets the furnished of this PropertySearchQuery.

        :param furnished: The furnished of this PropertySearchQuery.
        :type: bool
        """

        self._furnished = furnished

    @property
    def new_build(self):
        """
        Gets the new_build of this PropertySearchQuery.

        :return: The new_build of this PropertySearchQuery.
        :rtype: bool
        """
        return self._new_build

    @new_build.setter
    def new_build(self, new_build):
        """
        Sets the new_build of this PropertySearchQuery.

        :param new_build: The new_build of this PropertySearchQuery.
        :type: bool
        """

        self._new_build = new_build

    @property
    def missing_fields(self):
        """
        Gets the missing_fields of this PropertySearchQuery.

        :return: The missing_fields of this PropertySearchQuery.
        :rtype: list[str]
        """
        return self._missing_fields

    @missing_fields.setter
    def missing_fields(self, missing_fields):
        """
        Sets the missing_fields of this PropertySearchQuery.

        :param missing_fields: The missing_fields of this PropertySearchQuery.
        :type: list[str]
        """

        self._missing_fields = missing_fields

    @property
    def excluded_ids(self):
        """
        Gets the excluded_ids of this PropertySearchQuery.

        :return: The excluded_ids of this PropertySearchQuery.
        :rtype: list[str]
        """
        return self._excluded_ids

    @excluded_ids.setter
    def excluded_ids(self, excluded_ids):
        """
        Sets the excluded_ids of this PropertySearchQuery.

        :param excluded_ids: The excluded_ids of this PropertySearchQuery.
        :type: list[str]
        """

        self._excluded_ids = excluded_ids

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PropertySearchQuery):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class EvenementsadboxApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def adbox_events_count_group_by_group_by_and_sub_group_by_get(self, group_by, terms_size, sub_group_by, **kwargs):
        """
        Nombre de biens
        Retourne le nombre de biens regroupés selon 1 critère et 1 sous-critère.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.adbox_events_count_group_by_group_by_and_sub_group_by_get(group_by, terms_size, sub_group_by, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str group_by: Grouper par (required)
        :param int terms_size: Précision des résultats (required)
        :param str sub_group_by: Grouper par (required)
        :param int _from: Début de la pagination
        :param int size: Nombre de résultats
        :param str sort: Trier par
        :param list[str] includes: Inclure un ou plusieurs élements par identifiant
        :param list[str] excludes: Exclure un ou plusieurs élements par identifiant
        :param list[int] user_ids: Liste d'identifiants d'utilisateurs
        :param str status: Liste de statuts d'évènements
        :param str event_types: Liste de types d'évènements
        :param list[str] tags: Identifiants (UUID) de tags
        :param list[str] property_ids: Identifiants de biens
        :param datetime event_time_min: Date minimal de la création de l'évènement (YYYY-mm-ddTHH:mm:ss)
        :param datetime event_time_max: Date maximal de la création de l'évènement (YYYY-mm-ddTHH:mm:ss)
        :return: CountResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.adbox_events_count_group_by_group_by_and_sub_group_by_get_with_http_info(group_by, terms_size, sub_group_by, **kwargs)
        else:
            (data) = self.adbox_events_count_group_by_group_by_and_sub_group_by_get_with_http_info(group_by, terms_size, sub_group_by, **kwargs)
            return data

    def adbox_events_count_group_by_group_by_and_sub_group_by_get_with_http_info(self, group_by, terms_size, sub_group_by, **kwargs):
        """
        Nombre de biens
        Retourne le nombre de biens regroupés selon 1 critère et 1 sous-critère.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.adbox_events_count_group_by_group_by_and_sub_group_by_get_with_http_info(group_by, terms_size, sub_group_by, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str group_by: Grouper par (required)
        :param int terms_size: Précision des résultats (required)
        :param str sub_group_by: Grouper par (required)
        :param int _from: Début de la pagination
        :param int size: Nombre de résultats
        :param str sort: Trier par
        :param list[str] includes: Inclure un ou plusieurs élements par identifiant
        :param list[str] excludes: Exclure un ou plusieurs élements par identifiant
        :param list[int] user_ids: Liste d'identifiants d'utilisateurs
        :param str status: Liste de statuts d'évènements
        :param str event_types: Liste de types d'évènements
        :param list[str] tags: Identifiants (UUID) de tags
        :param list[str] property_ids: Identifiants de biens
        :param datetime event_time_min: Date minimal de la création de l'évènement (YYYY-mm-ddTHH:mm:ss)
        :param datetime event_time_max: Date maximal de la création de l'évènement (YYYY-mm-ddTHH:mm:ss)
        :return: CountResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_by', 'terms_size', 'sub_group_by', '_from', 'size', 'sort', 'includes', 'excludes', 'user_ids', 'status', 'event_types', 'tags', 'property_ids', 'event_time_min', 'event_time_max']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method adbox_events_count_group_by_group_by_and_sub_group_by_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_by' is set
        if ('group_by' not in params) or (params['group_by'] is None):
            raise ValueError("Missing the required parameter `group_by` when calling `adbox_events_count_group_by_group_by_and_sub_group_by_get`")
        # verify the required parameter 'terms_size' is set
        if ('terms_size' not in params) or (params['terms_size'] is None):
            raise ValueError("Missing the required parameter `terms_size` when calling `adbox_events_count_group_by_group_by_and_sub_group_by_get`")
        # verify the required parameter 'sub_group_by' is set
        if ('sub_group_by' not in params) or (params['sub_group_by'] is None):
            raise ValueError("Missing the required parameter `sub_group_by` when calling `adbox_events_count_group_by_group_by_and_sub_group_by_get`")

        if 'terms_size' in params and params['terms_size'] > 100:
            raise ValueError("Invalid value for parameter `terms_size` when calling `adbox_events_count_group_by_group_by_and_sub_group_by_get`, must be a value less than or equal to `100`")
        if 'terms_size' in params and params['terms_size'] < 10:
            raise ValueError("Invalid value for parameter `terms_size` when calling `adbox_events_count_group_by_group_by_and_sub_group_by_get`, must be a value greater than or equal to `10`")
        if '_from' in params and params['_from'] < 0:
            raise ValueError("Invalid value for parameter `_from` when calling `adbox_events_count_group_by_group_by_and_sub_group_by_get`, must be a value greater than or equal to `0`")
        if 'size' in params and params['size'] > 1000:
            raise ValueError("Invalid value for parameter `size` when calling `adbox_events_count_group_by_group_by_and_sub_group_by_get`, must be a value less than or equal to `1000`")
        if 'size' in params and params['size'] < 0:
            raise ValueError("Invalid value for parameter `size` when calling `adbox_events_count_group_by_group_by_and_sub_group_by_get`, must be a value greater than or equal to `0`")

        collection_formats = {}

        path_params = {}
        if 'group_by' in params:
            path_params['groupBy'] = params['group_by']
        if 'sub_group_by' in params:
            path_params['subGroupBy'] = params['sub_group_by']

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))
        if 'size' in params:
            query_params.append(('size', params['size']))
        if 'sort' in params:
            query_params.append(('sort', params['sort']))
        if 'includes' in params:
            query_params.append(('includes', params['includes']))
            collection_formats['includes'] = 'multi'
        if 'excludes' in params:
            query_params.append(('excludes', params['excludes']))
            collection_formats['excludes'] = 'multi'
        if 'user_ids' in params:
            query_params.append(('userIds', params['user_ids']))
            collection_formats['userIds'] = 'multi'
        if 'status' in params:
            query_params.append(('status', params['status']))
        if 'event_types' in params:
            query_params.append(('eventTypes', params['event_types']))
        if 'tags' in params:
            query_params.append(('tags', params['tags']))
            collection_formats['tags'] = 'multi'
        if 'property_ids' in params:
            query_params.append(('propertyIds', params['property_ids']))
            collection_formats['propertyIds'] = 'multi'
        if 'event_time_min' in params:
            query_params.append(('eventTimeMin', params['event_time_min']))
        if 'event_time_max' in params:
            query_params.append(('eventTimeMax', params['event_time_max']))
        if 'terms_size' in params:
            query_params.append(('termsSize', params['terms_size']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/adbox-events/count/group-by-{groupBy}-and-{subGroupBy}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='CountResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def adbox_events_count_group_by_group_by_get(self, group_by, terms_size, **kwargs):
        """
        Nombre de biens
        Retourne le nombre de biens regroupés selon 1 critère
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.adbox_events_count_group_by_group_by_get(group_by, terms_size, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str group_by: Grouper par (required)
        :param int terms_size: Précision des résultats (required)
        :param int _from: Début de la pagination
        :param int size: Nombre de résultats
        :param str sort: Trier par
        :param list[str] includes: Inclure un ou plusieurs élements par identifiant
        :param list[str] excludes: Exclure un ou plusieurs élements par identifiant
        :param list[int] user_ids: Liste d'identifiants d'utilisateurs
        :param str status: Liste de statuts d'évènements
        :param str event_types: Liste de types d'évènements
        :param list[str] tags: Identifiants (UUID) de tags
        :param list[str] property_ids: Identifiants de biens
        :param datetime event_time_min: Date minimal de la création de l'évènement (YYYY-mm-ddTHH:mm:ss)
        :param datetime event_time_max: Date maximal de la création de l'évènement (YYYY-mm-ddTHH:mm:ss)
        :return: CountResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.adbox_events_count_group_by_group_by_get_with_http_info(group_by, terms_size, **kwargs)
        else:
            (data) = self.adbox_events_count_group_by_group_by_get_with_http_info(group_by, terms_size, **kwargs)
            return data

    def adbox_events_count_group_by_group_by_get_with_http_info(self, group_by, terms_size, **kwargs):
        """
        Nombre de biens
        Retourne le nombre de biens regroupés selon 1 critère
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.adbox_events_count_group_by_group_by_get_with_http_info(group_by, terms_size, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str group_by: Grouper par (required)
        :param int terms_size: Précision des résultats (required)
        :param int _from: Début de la pagination
        :param int size: Nombre de résultats
        :param str sort: Trier par
        :param list[str] includes: Inclure un ou plusieurs élements par identifiant
        :param list[str] excludes: Exclure un ou plusieurs élements par identifiant
        :param list[int] user_ids: Liste d'identifiants d'utilisateurs
        :param str status: Liste de statuts d'évènements
        :param str event_types: Liste de types d'évènements
        :param list[str] tags: Identifiants (UUID) de tags
        :param list[str] property_ids: Identifiants de biens
        :param datetime event_time_min: Date minimal de la création de l'évènement (YYYY-mm-ddTHH:mm:ss)
        :param datetime event_time_max: Date maximal de la création de l'évènement (YYYY-mm-ddTHH:mm:ss)
        :return: CountResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_by', 'terms_size', '_from', 'size', 'sort', 'includes', 'excludes', 'user_ids', 'status', 'event_types', 'tags', 'property_ids', 'event_time_min', 'event_time_max']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method adbox_events_count_group_by_group_by_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_by' is set
        if ('group_by' not in params) or (params['group_by'] is None):
            raise ValueError("Missing the required parameter `group_by` when calling `adbox_events_count_group_by_group_by_get`")
        # verify the required parameter 'terms_size' is set
        if ('terms_size' not in params) or (params['terms_size'] is None):
            raise ValueError("Missing the required parameter `terms_size` when calling `adbox_events_count_group_by_group_by_get`")

        if 'terms_size' in params and params['terms_size'] > 100:
            raise ValueError("Invalid value for parameter `terms_size` when calling `adbox_events_count_group_by_group_by_get`, must be a value less than or equal to `100`")
        if 'terms_size' in params and params['terms_size'] < 10:
            raise ValueError("Invalid value for parameter `terms_size` when calling `adbox_events_count_group_by_group_by_get`, must be a value greater than or equal to `10`")
        if '_from' in params and params['_from'] < 0:
            raise ValueError("Invalid value for parameter `_from` when calling `adbox_events_count_group_by_group_by_get`, must be a value greater than or equal to `0`")
        if 'size' in params and params['size'] > 1000:
            raise ValueError("Invalid value for parameter `size` when calling `adbox_events_count_group_by_group_by_get`, must be a value less than or equal to `1000`")
        if 'size' in params and params['size'] < 0:
            raise ValueError("Invalid value for parameter `size` when calling `adbox_events_count_group_by_group_by_get`, must be a value greater than or equal to `0`")

        collection_formats = {}

        path_params = {}
        if 'group_by' in params:
            path_params['groupBy'] = params['group_by']

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))
        if 'size' in params:
            query_params.append(('size', params['size']))
        if 'sort' in params:
            query_params.append(('sort', params['sort']))
        if 'includes' in params:
            query_params.append(('includes', params['includes']))
            collection_formats['includes'] = 'multi'
        if 'excludes' in params:
            query_params.append(('excludes', params['excludes']))
            collection_formats['excludes'] = 'multi'
        if 'user_ids' in params:
            query_params.append(('userIds', params['user_ids']))
            collection_formats['userIds'] = 'multi'
        if 'status' in params:
            query_params.append(('status', params['status']))
        if 'event_types' in params:
            query_params.append(('eventTypes', params['event_types']))
        if 'tags' in params:
            query_params.append(('tags', params['tags']))
            collection_formats['tags'] = 'multi'
        if 'property_ids' in params:
            query_params.append(('propertyIds', params['property_ids']))
            collection_formats['propertyIds'] = 'multi'
        if 'event_time_min' in params:
            query_params.append(('eventTimeMin', params['event_time_min']))
        if 'event_time_max' in params:
            query_params.append(('eventTimeMax', params['event_time_max']))
        if 'terms_size' in params:
            query_params.append(('termsSize', params['terms_size']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/adbox-events/count/group-by-{groupBy}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='CountResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des
    demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le
    protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges
    de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous
    [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous
    permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de
    passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par
    votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête
    `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer
    Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton
    `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le
    boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.
    **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est
    pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API.

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages

NAME = "yanport-client"
VERSION = "1.0.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Yanport API client library",
    author_email="dev@yanport.com",
    url="",
    keywords=["Swagger", "Yanport API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des 
    demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le 
    protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de 
    données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous 
    [contacter](https://www.yanport.com/contact) afin d&#39;obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui 
    vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s&#39;authentifier 
    est de passer à chaque requêtes le token dans le header &#x60;Authorization: Bearer {{ JWT }}&#x60; en remplaçant 
    &#x60;{{ JWT }}&#x60; par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en 
    query param de la requête &#x60;https://api.yanport.com/?token&#x3D;{{ JWT }}&#x60;. (_privilégié le passage par 
    header en production._) ## Pour démarrer Lorsque vous disposez de votre token d&#39;authentification, vous pouvez 
    commencer à explorer notre API grâce au boutton  &#x60;Try it out&#x60; sur chacun de nos webs services. Mais au 
    préalable, vous devez vous authentifier en cliquant sur le boutton &#x60;Authorize &#x60;, en remplissant 
    l&#39;input &#x60;api_key&#x60; avec &#x60;Bearer {{ JWT }}&#x60;.  **Exemple** &#x60;
    Bearer eyUEkiLCJh...CHCUiBfD63oxoo&#x3D;&#x60; ## Limitation Toutes les requêtes à notre API sont loggées, c&#39;est 
    pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d&#39;éviter tout usage abusif de notre API. 
    """
)
